@@ -945,17 +945,17 @@ class WordToken(models.Model):
                     outline['wasRepeated'] = 'True'
                 else:
                     outline['wasRepeated'] = 'False'
-        if form['category'] == 'B':
-            outline['Category'] = self.Category.Label
-        elif form['category'] == 'C':
-            outline['Category'] = lookupCat(self.WordType.Label)
+        if 'B' in form['category']:
+            outline['BuckeyeCategory'] = self.Category.Label
+        if 'C' in form['category']:
+            outline['CelexCategory'] = lookupCat(self.WordType.Label)
         if form['wordDuration']:
             outline['WordDuration'] = self.getDuration()
             outline['BaselineDur'] = self.WordType.getBaseDuration()
-        if form['frequency'] == 'B':
-            outline['frequency'] = self.WordType.getFreq()
-        elif form['frequency'] == 'C':
-            outline['frequency'] = lookupFreq(self.WordType.Label)
+        if 'B' in form['frequency']:
+            outline['BuckeyeFrequency'] = self.WordType.getFreq()
+        if 'C' in form['frequency']:
+            outline['CelexFrequency'] = lookupFreq(self.WordType.Label)
         if form['gender']:
             outline['SpeakerGender'] = self.Dialog.Speaker.Gender
         if form['age']:
@@ -965,16 +965,16 @@ class WordToken(models.Model):
             outline['OrthoLength'] = len(self.WordType.Label)
         if form['phonoLength']:
             outline['PhonoLength'] = self.WordType.UR.count()
-        if form['nd'] == 'B':
-            outline['NeighDen'],outline['FWND'] = self.WordType.getNDs()
-        elif form['nd'] == 'PS':
-            outline['NeighDen'] = getNeighCount(self.WordType.getStrUR(),no_stress=True)
-        if form['phonotactic'] == 'VB':
-            outline['SPhoneProb'],outline['BiPhoneProb'] = self.WordType.getPhonoProb()
-        elif form['phonotactic'] == 'B':
-            outline['BlickPhono'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=True,no_stress=True)
-        elif form['phonotactic'] == 'VP':
-            outline['SPhoneProb'],outline['BiPhoneProb'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
+        if 'B' in form['nd']:
+            outline['BuckeyeNeighDen'],outline['BuckeyeFWND'] = self.WordType.getNDs()
+        if 'PS' in form['nd']:
+            outline['PhonoStatsNeighDen'] = getNeighCount(self.WordType.getStrUR(),no_stress=True)
+        if 'VB' in form['phonotactic']:
+            outline['BuckeyeSPhoneProb'],outline['BuckeyeBiPhoneProb'] = self.WordType.getPhonoProb()
+        if 'B' in form['phonotactic']:
+            outline['PhonoStatsBlickPhono'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=True,no_stress=True)
+        if 'VP' in form['phonotactic']:
+            outline['PhonoStatsSPhoneProb'],outline['PhonoStatsBiPhoneProb'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
         if form['prev_sem_pred']:
             outline['PrevSemPred'] = self.getPrevSemPred()
             outline['ImmedSemPred'] = self.getImmediateSemPred()
